==> netdata_1.12.0.orig.tar.xz: netdata-1.12.0/packaging/maintainers/README.md <==
# Package Maintainers

This page tracks the package maintainers for netdata, for various operating systems and versions.

> Feel free to update it, so that it reflects the current status.


---

## Official Linux Distributions

| Linux Distribution | Netdata Version | Maintainer | Related URL |
| :-: | :-: | :-: | :-- |
| Arch Linux | Release | @svenstaro | [netdata @ Arch Linux](https://www.archlinux.org/packages/community/x86_64/netdata/) |
| Arch Linux AUR | Git | @sanskritfritz | [netdata @ AUR](https://aur.archlinux.org/packages/netdata-git/) |
| Gentoo Linux | Release + Git | @candrews | [netdata @ gentoo](https://github.com/gentoo/gentoo/tree/master/net-analyzer/netdata) |
| Debian | Release | @lhw @FedericoCeratto | [netdata @ debian](http://salsa.debian.org/debian/netdata) |
| Slackware | Release | @willysr | [netdata @ slackbuilds](https://slackbuilds.org/repository/14.2/system/netdata/) |
| Ubuntu |  |  |  |
| Red Hat / Fedora / Centos |  |  |  |
| SUSE SLE / openSUSE Tumbleweed & Leap |  |  | [netdata @ SUSE OpenBuildService](https://software.opensuse.org/package/netdata) |

---
## FreeBSD

| System | Initial PR | Core Developer | Package Maintainer
|:-:|:-:|:-:|:-:|
FreeBSD|#1321|@vlvkobal|@mmokhi

---
## MacOS

| System | URL | Core Developer | Package Maintainer
|:-:|:-:|:-:|:-:|
MacOS Homebrew Formula|[link](https://github.com/Homebrew/homebrew-core/blob/master/Formula/netdata.rb)|@vlvkobal|@rickard-von-essen

---
## Unofficial Linux Packages

| Linux Distribution | Netdata Version | Maintainer | Related URL |
| :-: | :-: | :-: | :-- |
| Ubuntu | Release | @gslin | [netdata @ gslin ppa](https://launchpad.net/~gslin/+archive/ubuntu/netdata) https://github.com/netdata/netdata/issues/69#issuecomment-217458543 |

---
## Embedded Linux

| Embedded Linux | Netdata Version | Maintainer | Related URL |
| :-: | :-: | :-: | :-- |
| ASUSTOR NAS | ? | William Lin | https://www.asustor.com/apps/app_detail?id=532 |
| OpenWRT | Release | @nitroshift | [openwrt package](https://github.com/openwrt/packages/tree/master/admin/netdata) |
| ReadyNAS | Release | @NAStools | https://github.com/nastools/netdata |
| QNAP | Release | QNAP_Stephane | https://forum.qnap.com/viewtopic.php?t=121518 |
| DietPi | Release | @Fourdee | https://github.com/Fourdee/DietPi |

---
## Linux Containers

| Containers | Netdata Version | Maintainer | Related URL |
| :-: | :-: | :-: | :-- |
| Docker | Git | @titpetric | https://github.com/titpetric/netdata |

---
## Automation Systems

| Automation Systems | Netdata Version | Maintainer | Related URL |
| :-: | :-: | :-: | :-- |
| Ansible | git | @jffz | https://galaxy.ansible.com/jffz/netdata/ |
| Chef | ? | @sergiopena | https://github.com/sergiopena/netdata-cookbook |

---
## Packages summary from repology.org

[![Packaging status](https://repology.org/badge/vertical-allrepos/netdata.svg)](https://repology.org/metapackage/netdata/versions)

[![analytics](https://www.google-analytics.com/collect?v=1&aip=1&t=pageview&_s=1&ds=github&dr=https%3A%2F%2Fgithub.com%2Fnetdata%2Fnetdata&dl=https%3A%2F%2Fmy-netdata.io%2Fgithub%2Fpackaging%2Fmaintainers%2FREADME&_u=MAC~&cid=5792dfd7-8dc4-476b-af31-da2fdb9f93d2&tid=UA-64295674-3)]()

==> netdata_1.29.3.orig.tar.xz: netdata-1.29.3/packaging/maintainers/README.md <==
<!--
title: "Package Maintainers"
date: 2020-03-31
custom_edit_url: https://github.com/netdata/netdata/edit/master/packaging/maintainers/README.md
-->

# Package Maintainers

This page tracks the package maintainers for Netdata, for various operating systems and versions.

> Feel free to update it, so that it reflects the current status.

---

## Official Linux Distributions

| Linux Distribution | Netdata Version | Maintainer | Related URL |
| :-: | :-: | :-: | :-- |
| Arch Linux | Release | @svenstaro | [netdata @ Arch Linux](https://www.archlinux.org/packages/community/x86_64/netdata/) |
| Arch Linux AUR | Git | @sanskritfritz | [netdata @ AUR](https://aur.archlinux.org/packages/netdata-git/) |
| Gentoo Linux | Release + Git | @candrews | [netdata @ gentoo](https://github.com/gentoo/gentoo/tree/master/net-analyzer/netdata) |
| Debian | Release | @lhw @FedericoCeratto | [netdata @ debian](http://salsa.debian.org/debian/netdata) |
| Slackware | Release | @willysr | [netdata @ slackbuilds](https://slackbuilds.org/repository/14.2/system/netdata/) |
| Ubuntu |  |  |  |
| Red Hat / Fedora / CentOS |  |  |  |
| SUSE SLE / openSUSE Tumbleweed & Leap |  |  | [netdata @ SUSE OpenBuildService](https://software.opensuse.org/package/netdata) |

---

## FreeBSD

| System  | Initial PR | Core Developer | Package Maintainer
|:-:|:-:|:-:|:-:|
| FreeBSD | #1321      | @vlvkobal|@mmokhi

---

## macOS

| System | URL | Core Developer | Package Maintainer
|:-:|:-:|:-:|:-:|
| macOS Homebrew Formula|[link](https://github.com/Homebrew/homebrew-core/blob/master/Formula/netdata.rb)|@vlvkobal|@rickard-von-essen

---

## Unofficial Linux Packages

| Linux Distribution | Netdata Version | Maintainer | Related URL |
| :-: | :-: | :-: | :-- |
| Ubuntu             | Release         | @gslin     | [netdata @ gslin ppa](https://launchpad.net/~gslin/+archive/ubuntu/netdata) https://github.com/netdata/netdata/issues/69#issuecomment-217458543 |
---

## Embedded Linux

| Embedded Linux | Netdata Version | Maintainer | Related URL |
| :-: | :-: | :-: | :-- |
| ASUSTOR NAS | ? | William Lin | https://www.asustor.com/apps/app_detail?id=532 |
| OpenWRT | Release | @nitroshift | [openwrt package](https://github.com/openwrt/packages/tree/master/admin/netdata) |
| ReadyNAS | Release | @NAStools | https://github.com/nastools/netdata |
| QNAP | Release | QNAP_Stephane | https://forum.qnap.com/viewtopic.php?t=121518 |
| DietPi | Release | @Fourdee | https://github.com/Fourdee/DietPi |

---

## Linux Containers

| Containers | Netdata Version | Maintainer | Related URL |
| :-: | :-: | :-: | :-- |
| Docker     | Git             | @titpetric | https://github.com/titpetric/netdata |

---

## Automation Systems

| Automation Systems | Netdata Version | Maintainer | Related URL |
| :-: | :-: | :-: | :-- |
| Ansible            | git             | @jffz | https://galaxy.ansible.com/jffz/netdata/ |
| Chef               | ?               | @sergiopena | https://github.com/sergiopena/netdata-cookbook |

---

## Packages summary from repology.org

[![Packaging status](https://repology.org/badge/vertical-allrepos/netdata.svg)](https://repology.org/metapackage/netdata/versions)

[![analytics](https://www.google-analytics.com/collect?v=1&aip=1&t=pageview&_s=1&ds=github&dr=https%3A%2F%2Fgithub.com%2Fnetdata%2Fnetdata&dl=https%3A%2F%2Fmy-netdata.io%2Fgithub%2Fpackaging%2Fmaintainers%2FREADME&_u=MAC~&cid=5792dfd7-8dc4-476b-af31-da2fdb9f93d2&tid=UA-64295674-3)](<>)
